@@ -154,11 +154,19 @@ class WorkbenchMenu:
                         "Index the folder",
                         lambda: self.index_folder(self.cwd)
                     ),
-                    ("Browse all datasets", self.browse_home),
                     ("Exit", self.exit)
                 ]
             )
 
+        # If the dataset is not in the collection
+        if not self.wb.datasets.path_exists(self.cwd):
+
+            # Add it to the collection
+            self.wb.add_to_home_tree(ds, self.cwd)
+
+            # Add it to the dataset collection
+            self.wb.datasets.add(ds)
+
     def main_menu(self):
         """Show the main menu"""
 
@@ -267,15 +275,24 @@ class WorkbenchMenu:
     def explore_datasets_menu(self):
         """Inspect and navigate the available indexed datasets."""
 
+        choices = [
+            ("List All Datasets", self.list_all_datasets),
+            ("Add/Remove Dataset Filters", self.add_remove_filters),
+            ("Import Existing Dataset", self.import_folder)
+        ]
+
+        if len(self.wb.datasets.filtered_paths(sep=" : ")) > 0:
+            choices.append(
+                ("Change Directory", self.jump_directory_menu)
+            )
+
+        choices.append(
+            ("Back to Main Menu", self.main_menu)
+        )
+
         self.select_func(
             """Would you like to:""",
-            [
-                ("List All Datasets", self.list_all_datasets),
-                ("Add/Remove Dataset Filters", self.add_remove_filters),
-                ("Import Existing Dataset", self.import_folder),
-                ("Change Directory", self.jump_directory_menu),
-                ("Back to Main Menu", self.main_menu)
-            ]
+            choices
         )
 
     def print_line(self, text, indent=0, leader="- "):
@@ -447,6 +464,9 @@ class WorkbenchMenu:
             if len(repo.assets.get(asset_type, [])) > 0
         ]
 
+        # Sort the list alphabetically
+        repository_choices.sort()
+
         # Give the option to go back
         repository_choices.append("Back")
 
@@ -897,8 +917,11 @@ class WorkbenchMenu:
             # Tail the logs
             self.tail_logs()
 
-        # Return to the main menu
-        self.main_menu()
+        # Otherwise
+        else:
+
+            # Return to the main menu
+            self.main_menu()
 
     def setup_tool_menu(self):
         """Set up a tool for a dataset."""
@@ -1154,6 +1177,9 @@ class WorkbenchMenu:
                     # Run the action
                     ds.run_action(user_choice)
 
+        # When all done, return to the main menu
+        self.main_menu()
+
     def erase_lines(self, n_lines:int):
         """Erase a number of lines from the display"""
 
@@ -1201,6 +1227,12 @@ class WorkbenchMenu:
             only_directories=True
         )
 
+        # If the user selected the home directory with a tilde
+        if folder_to_import.startswith("~"):
+
+            # Replace the tilde with the home directory
+            folder_to_import = f"{self.wb.filelib.home()}{folder_to_import[1:]}"
+
         # Try to add the folder
         try:
             self.wb.index_folder(folder_to_import)
@@ -1215,8 +1247,8 @@ class WorkbenchMenu:
         # Report success
         self.print_line(f"Imported folder {folder_to_import}")
 
-        # Back to the main menu
-        self.main_menu()
+        # Back to the Explore Datasets menu
+        self.explore_datasets_menu()
     
     def manage_repositories_menu(self):
         """Manage the repositories available"""
@@ -1244,6 +1276,9 @@ class WorkbenchMenu:
         # Get the list of repositories which have been downloaded
         local_repos = self.wb.list_repos()
 
+        # Sort the list
+        local_repos.sort()
+
         # Add an option for each of the downloaded repositories
         for repo in local_repos:
             choices.append(f"Manage repository: {repo}")
@@ -1368,11 +1403,7 @@ class WorkbenchMenu:
 
         # Print the version of the local repository
         if self.wb.repositories[repo_name].repo is not None:
-            hexsha = self.wb.repositories[repo_name].repo.head.object.hexsha
-            self.print_line(f"Branch name: {self.wb.repositories[repo_name].repo.head.name}")
-            committed_date = strftime("%a, %d %b %Y %H:%M", gmtime(self.wb.repositories[repo_name].repo.head.object.committed_date))
-            self.print_line(f"Commit date: {committed_date}")
-            self.print_line(f"Commit hash: {hexsha}")
+            self.print_repo_version(repo_name)
 
         # Ask the user what to do
         self.select_func(
@@ -1385,6 +1416,14 @@ class WorkbenchMenu:
             ]
         )
 
+    def print_repo_version(self, repo_name:str) -> None:
+        """Print the version of a repo."""
+        hexsha = self.wb.repositories[repo_name].repo.head.object.hexsha
+        self.print_line(f"Branch name: {self.wb.repositories[repo_name].repo.head.name}")
+        committed_date = strftime("%a, %d %b %Y %H:%M", gmtime(self.wb.repositories[repo_name].repo.head.object.committed_date))
+        self.print_line(f"Commit date: {committed_date}")
+        self.print_line(f"Commit hash: {hexsha}")
+
     def update_local_repo(self, repo_name):
         """Update a local repository to the most recent version."""
 
@@ -1406,6 +1445,9 @@ class WorkbenchMenu:
         # Update the list of Repositories which are available
         self.wb.repositories = self.wb.setup_repositories()
 
+        # Print the updated repo version
+        self.print_repo_version(repo_name)
+
         # Go back to the repository menu
         self.manage_repositories_menu()
 
@@ -1457,6 +1499,9 @@ class WorkbenchMenu:
         # Update the list of Repositories which are available
         self.wb.repositories = self.wb.setup_repositories()
 
+        # Print the updated repo version
+        self.print_repo_version(repo_name)
+
         # Go back to the repository menu
         self.manage_repositories_menu()
 
@@ -1471,20 +1516,6 @@ class WorkbenchMenu:
 
             self.print_line(f"{key}: {val}")
 
-    def browse_home(self):
-        """Navigate to the top-level home directory."""
-
-        # Directory containing all datasets
-        data_dir = self.wb._top_level_folder("data")
-
-        self.print_line(f"Changing working directory to {data_dir}")
-
-        # Change the working directory
-        self.cwd = data_dir
-
-        # Go back to the main menu
-        self.main_menu()
-
     def exit(self):
         """Exit the interactive display."""
 
